/* MenuRadioButton.java
 * =========================================================================
 * This file is part of the SWIRL Library - http://swirl-lib.sourceforge.net
 * 
 * Copyright (C) 2005-2008 Universiteit Gent
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * A copy of the GNU General Public License can be found in the file
 * LICENSE.txt provided with the source distribution of this program (see
 * the META-INF directory in the source jar). This license can also be
 * found on the GNU website at http://www.gnu.org/licenses/gpl.html.
 * 
 * If you did not receive a copy of the GNU General Public License along
 * with this program, contact the lead developer, or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 * 
 */

package be.ugent.caagt.swirl.actions;

import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JRadioButtonMenuItem;

/**
 * Radio button for use in a menu. Has the same functionality as
 * {@link JRadioButtonMenuItem} but also honours the action keys
 * {@link SimpleAction#SMALL_DISABLED_ICON} and {@link SimpleAction#TOGGLE_BUTTON_MODEL}.
 */
public class MenuRadioButton extends JRadioButtonMenuItem {

    /**
     * Create a menu button from the given action. Results in a button
     * which is almost the same as a standard Swing {@code JRadioButtonMenuItem} except that
     * it also honours the action keys {@link SimpleAction#SMALL_DISABLED_ICON}
     * and {@link SimpleAction#TOGGLE_BUTTON_MODEL}.
     */
    public MenuRadioButton(Action action) {
        super(action);
    }

    // overrides AbstractButton
    @Override
    protected void configurePropertiesFromAction(Action a) {
        super.configurePropertiesFromAction(a);
        MenuButtonSupport.configureMorePropertiesFromAction(this, a);
        ToolBarButtonSupport.configureModelFromAction(this, a);
    }

    // overrides AbstractButton
    @Override
    protected PropertyChangeListener createActionPropertyChangeListener(Action a) {
        return MenuButtonSupport.createActionPropertyChangeListener(
                this,
                super.createActionPropertyChangeListener(a));
    }
}
